;; Copyright (C) 2024  Felisp
;;
;; This program is free software: you can redistribute it and/or modify
;; it under the terms of the GNU Affero General Public License as published by
;; the Free Software Foundation, version 3 of the License.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU Affero General Public License for more details.
;;
;; You should have received a copy of the GNU Affero General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

(ns rss-thread-watch.filters
  "Functions filtering posts"
  (:require [clojure.string :as cs])
  (:gen-class))

(defn case-sensitive-filter
  "Returns true if string [s] is matched by any query. It's case insensitive"
  [{:keys [title]} queries]
  (some (fn [querry]
          (cs/includes? title querry))
        queries))

(defn case-insensitive-filter
  "Returns true if string [s] is case-matched by query"
  [{:keys [title]} queries]
  (case-sensitive-filter {:title (cs/lower-case title)} (map cs/lower-case queries)))

(def known-filters
  {"Q" case-sensitive-filter
   "q" case-insensitive-filter})

(def known-filter-set (set (keys known-filters)))

